#include <stdio.h>
#include <stdlib.h>

#include <openssl/ssl.h>

static void
do_assert (int retcode)
{
  if (retcode != 1)
    exit (EXIT_FAILURE);
}


static void
usage (void)
{
  fprintf (stderr, "Usage: certvalidate [certfile] [keyfile]\n");
  exit (EXIT_FAILURE);
}

int
main (int argc, char **argv)
{
  SSL_CTX *ctx;

  if (argc < 3)
    usage ();

#if OPENSSL_VERSION_NUMBER < 0x10100000L
  SSL_library_init ();
#else
  OPENSSL_init_ssl (0, NULL);
#endif

#if OPENSSL_VERSION_NUMBER < 0x10100000L
  ctx = SSL_CTX_new (SSLv23_server_method ());
#else
  ctx = SSL_CTX_new (TLS_server_method ());
#endif

  do_assert (SSL_CTX_use_certificate_file (ctx, argv[1], SSL_FILETYPE_PEM));
  do_assert (SSL_CTX_use_PrivateKey_file (ctx, argv[2], SSL_FILETYPE_PEM));
  do_assert (SSL_CTX_check_private_key (ctx));

  SSL_CTX_free (ctx);
  return EXIT_SUCCESS;
}
